package sk.upjs.js;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.validation.Errors;
import org.springframework.validation.ValidationUtils;
import org.springframework.validation.Validator;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

@Controller
@RequestMapping("/editStudent.do")
public class EditStudent {
	private static StudentValidator studentValidator = new StudentValidator();
	
	@Autowired
	private Database database;
	
	@RequestMapping(method = RequestMethod.GET)
	public String displayStudent(Integer studentId, ModelMap model) {
		
		Student student = null;
		if(studentId == null) {
			student = new Student();
		} else {
			student = database.findById(studentId);
		}
		if(student == null) {
			student = new Student();
		} 
		//adds as ["student", student]
		model.addAttribute(student);
		
		return "editStudent";
	}
	
	@RequestMapping(method = RequestMethod.POST)
	public String updateStudent(Student student, Errors errors) {
		studentValidator.validate(student, errors);
		if(errors.hasErrors()) {
			return "editStudent";
		}
		database.saveOrUpdate(student);
		
		return "redirect:listStudents.do";
	}
	
	public static class StudentValidator implements Validator {
		public boolean supports(Class clazz) {
			return Student.class.isAssignableFrom(clazz);
		}
		
		public void validate(Object target, Errors errors) {
			Student student = (Student) target;
			ValidationUtils.rejectIfEmptyOrWhitespace(errors, "meno", "", "Name cannot be empty.");
			ValidationUtils.rejectIfEmptyOrWhitespace(errors, "priezvisko", "", "Last name cannot be empty.");
			if(student.getRocnik() < 1 || student.getRocnik() > 5) {
				errors.rejectValue("rocnik", "", "Year must be between 1 and 5!");
			}
		}
	}
}
